##
##  websocketd.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_websocketd_base 0.4.1
%define       V_websocketd_snap 20230806

#   package information
Name:         websocketd
Summary:      Websocket to Process Connector Tool
URL:          http://websocketd.com/
Vendor:       Joe Walnes
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Web
License:      MIT
Version:      %{V_websocketd_base}.%{V_websocketd_snap}
Release:      20230806

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/websocketd/websocketd-%{V_websocketd_snap}.tar.xz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101

%description
    websocketd is a small command-line tool that will wrap an existing
    command-line interface program, and allow it to be accessed via a
    WebSocket. WebSocket-capable applications can now be built very
    easily. As long as you can write an executable program that reads
    STDIN and writes to STDOUT, you can build a WebSocket server.

%track
    prog websocketd:release = {
        version   = %{V_websocketd_base}
        url       = https://github.com/joewalnes/websocketd/releases
        regex     = tree/v(__VER__)
    }
    prog websocketd:snapshot = {
        version   = %{V_websocketd_snap}
        url       = http://download.openpkg.org/components/versioned/websocketd/
        regex     = websocketd-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n websocketd

%build
    #   build program
    export GOPATH=`pwd`
    cd src/github.com/joewalnes/websocketd
    go build -v -o bin/websocketd

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/github.com/joewalnes/websocketd/bin/websocketd \
        $RPM_BUILD_ROOT%{l_prefix}/bin/websocketd

    #   install manual page
    %{l_shtool} install -c -m 644 \
        src/github.com/joewalnes/websocketd/release/websocketd.man \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1/websocketd.1

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

